@@ -2,13 +2,14 @@ from __future__ import unicode_literals, division, absolute_import
 import re
 import urllib
 import logging
-from flexget.plugins.plugin_urlrewriting import UrlRewritingError
+
+from flexget import plugin
 from flexget.entry import Entry
-from flexget.plugin import register_plugin, internet, PluginWarning
+from flexget.event import event
+from flexget.plugins.plugin_urlrewriting import UrlRewritingError
 from flexget.utils import requests
 from flexget.utils.soup import get_soup
 from flexget.utils.search import torrent_availability, normalize_unicode
-from flexget import validator
 
 log = logging.getLogger('piratebay')
 
@@ -41,15 +42,25 @@ SORT = {
 class UrlRewritePirateBay(object):
     """PirateBay urlrewriter."""
 
-    def validator(self):
-        root = validator.factory()
-        root.accept('boolean')
-        advanced = root.accept('dict')
-        advanced.accept('choice', key='category').accept_choices(CATEGORIES)
-        advanced.accept('integer', key='category')
-        advanced.accept('choice', key='sort_by').accept_choices(SORT)
-        advanced.accept('boolean', key='sort_reverse')
-        return root
+    schema = {
+        'oneOf': [
+            {'type': 'boolean'},
+            {
+                'type': 'object',
+                'properties': {
+                    'category': {
+                        'oneOf': [
+                            {'type': 'string', 'enum': list(CATEGORIES)},
+                            {'type': 'integer'}
+                        ]
+                    },
+                    'sort_by': {'type': 'string', 'enum': list(SORT)},
+                    'sort_reverse': {'type': 'boolean'}
+                },
+                'additionalProperties': False
+            }
+        ]
+    }
 
     # urlrewriter API
     def url_rewritable(self, task, entry):
@@ -75,7 +86,7 @@ class UrlRewritePirateBay(object):
             # parse download page
             entry['url'] = self.parse_download_page(entry['url'])
 
-    @internet(log)
+    @plugin.internet(log)
     def parse_download_page(self, url):
         page = requests.get(url).content
         try:
@@ -92,7 +103,7 @@ class UrlRewritePirateBay(object):
         except Exception as e:
             raise UrlRewritingError(e)
 
-    @internet(log)
+    @plugin.internet(log)
     def search(self, arg_entry, config=None):
         """
         Search for name from piratebay.
@@ -140,4 +151,7 @@ class UrlRewritePirateBay(object):
 
         return sorted(entries, reverse=True, key=lambda x: x.get('search_sort'))
 
-register_plugin(UrlRewritePirateBay, 'piratebay', groups=['urlrewriter', 'search'])
+
+@event('plugin.register')
+def register_plugin():
+    plugin.register(UrlRewritePirateBay, 'piratebay', groups=['urlrewriter', 'search'], api_ver=2)
